==> uui-breadcrumbs-0.0.12.tgz: package/lib/uui-breadcrumbs.test.js <==
import { fixture, html as html$1, expect } from '@open-wc/testing';
import { css, LitElement, html } from 'lit';
import { property, queryAssignedNodes } from 'lit/decorators.js';
import { defineElement } from '@umbraco-ui/uui-base/lib/registration';

var __defProp$1 = Object.defineProperty;
var __getOwnPropDesc$1 = Object.getOwnPropertyDescriptor;
var __decorateClass$1 = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc$1(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp$1(target, key, result);
  return result;
};
class UUIBreadcrumbItemElement extends LitElement {
  constructor() {
    super(...arguments);
    this.href = "#";
    this.lastItem = false;
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "listitem");
  }
  render() {
    return html`${this.lastItem ? html`<span id="last-item"><slot></slot></span>` : html`<a id="link" href=${this.href}><slot></slot></a>`}<span
        part="separator"></span>`;
  }
}
UUIBreadcrumbItemElement.styles = [
  css`
      :host {
        font-size: var(--uui-size-4,12px);
        color: currentColor;
      }

      a,
      a:visited {
        color: currentColor;
      }

      :host(:last-of-type) [part='separator'],
      :host([last-item]) [part='separator'] {
        display: none;
      }

      [part='separator']::after {
        content: '/';
        speak: never;
        position: relative;
        top: 1px;
        margin: -3px 1px 0;
        color: var(--uui-interface-border, #c4c4c4);
      }

      #link,
      #last-item {
        padding: 0 4px;
        max-width: 150px;
        white-space: nowrap;
        overflow: hidden;
        text-overflow: ellipsis;
      }

      #link {
        cursor: pointer;
      }
    `
];
__decorateClass$1([
  property()
], UUIBreadcrumbItemElement.prototype, "href", 2);
__decorateClass$1([
  property({ type: Boolean, attribute: "last-item" })
], UUIBreadcrumbItemElement.prototype, "lastItem", 2);
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};
class UUIBreadcrumbsElement extends LitElement {
  _setLastItem() {
    if (this._breadcrumbs) {
      this._breadcrumbs[this._breadcrumbs.length - 1].lastItem = true;
      this._breadcrumbs[this._breadcrumbs.length - 1].setAttribute("aria-current", "page");
    }
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("aria-label", "breadcrumb");
    this.setAttribute("role", "navigation");
  }
  render() {
    return html`<ol id="breadcrumbs-list">
      <slot @slotchange=${this._setLastItem}></slot>
    </ol>`;
  }
}
UUIBreadcrumbsElement.styles = [
  css`
      :host {
        display: flex;
      }

      #breadcrumbs-list {
        display: flex;
        list-style-type: decimal;
        -webkit-margin-before: 0em;
                margin-block-start: 0em;
        -webkit-margin-after: 0em;
                margin-block-end: 0em;
        -webkit-margin-start: 0px;
                margin-inline-start: 0px;
        -webkit-margin-end: 0px;
                margin-inline-end: 0px;
        -webkit-padding-start: 0px;
                padding-inline-start: 0px;
      }
    `
];
__decorateClass([
  queryAssignedNodes(void 0, true, "uui-breadcrumb-item")
], UUIBreadcrumbsElement.prototype, "_breadcrumbs", 2);
defineElement("uui-breadcrumb-item", UUIBreadcrumbItemElement);
defineElement("uui-breadcrumbs", UUIBreadcrumbsElement);

describe("UuiBreadcrumbs", () => {
  let element;
  beforeEach(async () => {
    element = await fixture(html$1`
        <uui-breadcrumbs
          ><uui-breadcrumb-item>One</uui-breadcrumb-item
          ><uui-breadcrumb-item>Two</uui-breadcrumb-item
          ><uui-breadcrumb-item>Three</uui-breadcrumb-item>
        </uui-breadcrumbs>
      `);
  });
  it("renders a slot", () => {
    const slot = element.shadowRoot.querySelector("slot");
    expect(slot).to.exist;
  });
  it("sets the last element", () => {
    const slot = element.shadowRoot.querySelector("slot");
    const breadcrumb = slot.assignedElements()[2];
    expect(breadcrumb.lastItem).to.be.true;
  });
  it("passes the a11y audit", () => {
    expect(element).shadowDom.to.be.accessible();
  });
});

==> uui-breadcrumbs-0.0.16.tgz: package/lib/uui-breadcrumbs.test.js <==
import { fixture, html as html$1, expect } from '@open-wc/testing';
import { css, LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';
import { defineElement } from '@umbraco-ui/uui-base/lib/registration';

var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
typeof require !== "undefined" ? require : (x) => {
  throw new Error('Dynamic require of "' + x + '" is not supported');
};
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};
class UUIBreadcrumbItemElement extends LitElement {
  constructor() {
    super(...arguments);
    this.href = "#";
    this.lastItem = false;
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "listitem");
  }
  renderLinkAndSeparator() {
    return html`<a id="link" href=${this.href}><slot></slot></a
      ><span part="separator"></span>`;
  }
  renderCurrent() {
    return html`<span id="last-item"><slot></slot></span>`;
  }
  render() {
    return html`${this.lastItem ? this.renderCurrent() : this.renderLinkAndSeparator()}`;
  }
}
UUIBreadcrumbItemElement.styles = [
  css`
      :host {
        font-size: var(--uui-size-4,12px);
        color: currentColor;
      }

      a,
      a:visited {
        color: currentColor;
      }

      [part='separator']::after {
        content: '/';
        speak: never;
        position: relative;
        top: 1px;
        margin: -3px 1px 0;
        color: var(--uui-interface-border, #c4c4c4);
      }

      #link,
      #last-item {
        padding: 0 4px;
        max-width: 150px;
        white-space: nowrap;
        overflow: hidden;
        text-overflow: ellipsis;
      }

      #link {
        cursor: pointer;
      }
    `
];
__decorateClass([
  property()
], UUIBreadcrumbItemElement.prototype, "href", 2);
__decorateClass([
  property({ type: Boolean, attribute: "last-item" })
], UUIBreadcrumbItemElement.prototype, "lastItem", 2);
class UUIBreadcrumbsElement extends LitElement {
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("aria-label", "breadcrumb");
    this.setAttribute("role", "navigation");
  }
  handleSlotChange() {
    const breadcrumbNodes = this.querySelectorAll("uui-breadcrumb-item");
    const breadcrumbs = Array.from(breadcrumbNodes);
    if ((breadcrumbs == null ? void 0 : breadcrumbs.length) > 0) {
      breadcrumbs[breadcrumbs.length - 1].lastItem = true;
      breadcrumbs[breadcrumbs.length - 1].setAttribute("aria-current", "page");
    }
  }
  render() {
    return html`<ol id="breadcrumbs-list">
      <slot @slotchange=${this.handleSlotChange}></slot>
    </ol>`;
  }
}
UUIBreadcrumbsElement.styles = [
  css`
      :host {
        display: flex;
      }

      #breadcrumbs-list {
        display: flex;
        list-style-type: decimal;
        -webkit-margin-before: 0em;
                margin-block-start: 0em;
        -webkit-margin-after: 0em;
                margin-block-end: 0em;
        -webkit-margin-start: 0px;
                margin-inline-start: 0px;
        -webkit-margin-end: 0px;
                margin-inline-end: 0px;
        -webkit-padding-start: 0px;
                padding-inline-start: 0px;
      }
    `
];
defineElement("uui-breadcrumb-item", UUIBreadcrumbItemElement);
defineElement("uui-breadcrumbs", UUIBreadcrumbsElement);

describe("UuiBreadcrumbs", () => {
  let element;
  beforeEach(async () => {
    element = await fixture(html$1`
        <uui-breadcrumbs
          ><uui-breadcrumb-item>One</uui-breadcrumb-item
          ><uui-breadcrumb-item>Two</uui-breadcrumb-item
          ><uui-breadcrumb-item>Three</uui-breadcrumb-item>
        </uui-breadcrumbs>
      `);
  });
  it("renders a slot", () => {
    const slot = element.shadowRoot.querySelector("slot");
    expect(slot).to.exist;
  });
  it("sets the last element", () => {
    const slot = element.shadowRoot.querySelector("slot");
    const breadcrumb = slot.assignedElements()[2];
    expect(breadcrumb.lastItem).to.be.true;
  });
  it("passes the a11y audit", () => {
    expect(element).shadowDom.to.be.accessible();
  });
});
